@@ -45,7 +45,7 @@ class ASGI:
 				await response.abort(status=404)
 			try:
 				body = await method(request, response, *url_args)
-			except ParseError:
+			except InputParseError:
 				await response.abort(status=400)
 			if not response.processed:
 				await response.process(body)
